#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppEbppBillkeyDeductQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppEbppBillkeyDeductQueryResponse, self).__init__()
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._open_id = None
        self._sub_biz_type = None
        self._user_id = None

    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppEbppBillkeyDeductQueryResponse, self).parse_response_content(response_content)
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'sub_biz_type' in response:
            self.sub_biz_type = response['sub_biz_type']
        if 'user_id' in response:
            self.user_id = response['user_id']
